list constant

  1. @BuiltValueEnumConst.new(wireName: r'list')
CreateProjectNormalizedPayloadHydraStrategiesJwtScopeClaimEnum const list

Define the claim to use as the scope in the access token. This governs the "strategies.jwt.scope_claim" setting: list: The scope claim is an array of strings named scope: { \"scope\": [\"read\", \"write\"] } string: The scope claim is a space delimited list of strings named scp: { \"scp\": \"read write\" } both: The scope claim is both a space delimited list and an array of strings named scope and scp: { \"scope\": [\"read\", \"write\"], \"scp\": \"read write\" } list OAuth2JWTScopeClaimList string OAuth2JWTScopeClaimString both OAuth2JWTScopeClaimBoth

Implementation

@BuiltValueEnumConst(wireName: r'list')
static const CreateProjectNormalizedPayloadHydraStrategiesJwtScopeClaimEnum list = _$createProjectNormalizedPayloadHydraStrategiesJwtScopeClaimEnum_list;